@@ -1,8 +1,10 @@
-{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE CPP, FlexibleContexts, MultiParamTypeClasses #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module System.Process.Text where
 
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ((<$>))
+#endif
 import Control.Monad
 import Data.ListLike.IO (hGetContents)
 import Data.Text (Text)
@@ -11,6 +13,8 @@ import System.Process
 import System.Process.Common
 import System.Exit (ExitCode)
 
+instance ProcessText Text Char
+
 -- | Like 'System.Process.readProcessWithExitCode', but using 'Text'
 instance ListLikeProcessIO Text Char where
     forceOutput = return
