@@ -1,21 +1,25 @@
-{-# LANGUAGE MultiParamTypeClasses #-}
+{-# LANGUAGE CPP, MultiParamTypeClasses #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module System.Process.Text.Lazy where
 
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ((<$>))
+#endif
 import Control.DeepSeq (force)
 import qualified Control.Exception as C (evaluate)
 import Data.ListLike.IO (hGetContents)
-import Data.Text.Lazy (Text, fromChunks, toChunks)
+import Data.Text.Lazy (Text, fromStrict, toChunks)
 import Prelude hiding (null)
 import System.Process
 import System.Process.Common
 import System.Exit (ExitCode)
 
+instance ProcessText Text Char
+
 -- | Like 'System.Process.readProcessWithExitCode', but using 'Text'
 instance ListLikeProcessIO Text Char where
     forceOutput = C.evaluate . force
-    readChunks h = (map (fromChunks . (: [])) . toChunks) <$> hGetContents h
+    readChunks h = (map fromStrict . toChunks) <$> hGetContents h
 
 -- | Specialized version for backwards compatibility.
 readProcessWithExitCode
